@@ -35,8 +35,8 @@
    especially those whose name start with YY_ or yy_.  They are
    private implementation details that can be changed or removed.  */
 
-#ifndef YY_PKL_TAB_PKL_TAB_H_INCLUDED
-# define YY_PKL_TAB_PKL_TAB_H_INCLUDED
+#ifndef YY_PKL_TAB_PKL_TAB_TAB_H_INCLUDED
+# define YY_PKL_TAB_PKL_TAB_TAB_H_INCLUDED
 /* Debug traces.  */
 #ifndef PKL_TAB_DEBUG
 # if defined YYDEBUG
@@ -179,7 +179,7 @@ extern int pkl_tab_debug;
 #if ! defined PKL_TAB_STYPE && ! defined PKL_TAB_STYPE_IS_DECLARED
 union PKL_TAB_STYPE
 {
-#line 338 "../../libpoke/pkl-tab.y"
+#line 338 "pkl-tab.y"
 
   pkl_ast_node ast;
   enum pkl_ast_op opcode;
@@ -211,4 +211,4 @@ struct PKL_TAB_LTYPE
 
 int pkl_tab_parse (struct pkl_parser *pkl_parser);
 
-#endif /* !YY_PKL_TAB_PKL_TAB_H_INCLUDED  */
+#endif /* !YY_PKL_TAB_PKL_TAB_TAB_H_INCLUDED  */
