@@ -74,7 +74,7 @@
 #define yynerrs         pk_map_tab_nerrs
 
 /* First part of user prologue.  */
-#line 34 "../../poke/pk-map-tab.y"
+#line 34 "pk-map-tab.y"
 
 #include <config.h>
 
@@ -326,8 +326,8 @@ pk_map_tab_error (YYLTYPE *llocp, struct pk_map_parser *map_parser, char const *
 
 /* Use api.header.include to #include this header
    instead of duplicating it here.  */
-#ifndef YY_PK_MAP_TAB_PK_MAP_TAB_H_INCLUDED
-# define YY_PK_MAP_TAB_PK_MAP_TAB_H_INCLUDED
+#ifndef YY_PK_MAP_TAB_PK_MAP_TAB_TAB_H_INCLUDED
+# define YY_PK_MAP_TAB_PK_MAP_TAB_TAB_H_INCLUDED
 /* Debug traces.  */
 #ifndef PK_MAP_TAB_DEBUG
 # if defined YYDEBUG
@@ -366,7 +366,7 @@ extern int pk_map_tab_debug;
 #if ! defined PK_MAP_TAB_STYPE && ! defined PK_MAP_TAB_STYPE_IS_DECLARED
 union PK_MAP_TAB_STYPE
 {
-#line 263 "../../poke/pk-map-tab.y"
+#line 263 "pk-map-tab.y"
 
   char *string;
   int integer;
@@ -400,7 +400,7 @@ struct PK_MAP_TAB_LTYPE
 
 int pk_map_tab_parse (struct pk_map_parser *map_parser);
 
-#endif /* !YY_PK_MAP_TAB_PK_MAP_TAB_H_INCLUDED  */
+#endif /* !YY_PK_MAP_TAB_PK_MAP_TAB_TAB_H_INCLUDED  */
 /* Symbol kind.  */
 enum yysymbol_kind_t
 {
@@ -1548,7 +1548,7 @@ YYLTYPE yylloc = yyloc_default;
   yychar = PK_MAP_TAB_EMPTY; /* Cause a token to be read.  */
 
 /* User initialization code.  */
-#line 29 "../../poke/pk-map-tab.y"
+#line 29 "pk-map-tab.y"
 {
     yylloc.first_line = yylloc.last_line = 1;
     yylloc.first_column = yylloc.last_column = 1;
@@ -1764,7 +1764,7 @@ yyreduce:
   switch (yyn)
     {
   case 2:
-#line 291 "../../poke/pk-map-tab.y"
+#line 291 "pk-map-tab.y"
                 {
                   /* XXX sort the entries?  Maybe not.  */
                   (yyval.map) = make_map ("XXX", (yyvsp[-2].string), (yyvsp[0].entry));
@@ -1775,19 +1775,19 @@ yyreduce:
     break;
 
   case 3:
-#line 301 "../../poke/pk-map-tab.y"
+#line 301 "pk-map-tab.y"
                 { (yyval.entry) = NULL; }
 #line 1781 "pk-map-tab.c"
     break;
 
   case 4:
-#line 303 "../../poke/pk-map-tab.y"
+#line 303 "pk-map-tab.y"
                 { (yyval.entry) = map_entry_chainon ((yyvsp[-1].entry), (yyvsp[0].entry)); }
 #line 1787 "pk-map-tab.c"
     break;
 
   case 5:
-#line 307 "../../poke/pk-map-tab.y"
+#line 307 "pk-map-tab.y"
                   {
                   tagged_value name = get_tagged_value ((yyvsp[0].tagged_value), TAG_NAME);
                   tagged_value type = get_tagged_value ((yyvsp[0].tagged_value), TAG_TYPE);
@@ -1827,19 +1827,19 @@ yyreduce:
     break;
 
   case 6:
-#line 346 "../../poke/pk-map-tab.y"
+#line 346 "pk-map-tab.y"
                 { (yyval.tagged_value) = NULL; }
 #line 1833 "pk-map-tab.c"
     break;
 
   case 7:
-#line 348 "../../poke/pk-map-tab.y"
+#line 348 "pk-map-tab.y"
                 { (yyval.tagged_value) = tagged_value_chainon ((yyvsp[-1].tagged_value), (yyvsp[0].tagged_value)); }
 #line 1839 "pk-map-tab.c"
     break;
 
   case 8:
-#line 353 "../../poke/pk-map-tab.y"
+#line 353 "pk-map-tab.y"
           {
             if ((yyvsp[-1].integer) == TAG_UNKNOWN)
               {
@@ -2084,7 +2084,7 @@ yyreturn:
   return yyresult;
 }
 
-#line 365 "../../poke/pk-map-tab.y"
+#line 365 "pk-map-tab.y"
 
 
 /* Parser public functions.  */
@@ -2093,7 +2093,6 @@ pk_map_parsed_map
 pk_map_parse_file (const char *filename, FILE *fp)
 {
   int ret;
-  char *stderr;
   struct pk_map_parser map_parser;
 
   map_parser.map = NULL;
